angular.module('starter.controllers', [])

.controller('MenuCtrl', function($scope, Filter, $ionicLoading, $timeout, $state, $ionicHistory, $ionicViewService) {
  $scope.registerLink = function() {
    $state.go('app.register');
  };
  $scope.loginLink = function() {
    $state.go('app.login');
  };

  $scope.searchLink = function() {
    // disable back button
    $ionicViewService.nextViewOptions({
      disableAnimate: true,
      disableBack: true
    });
    $state.go('app.search', {}, {reload: true});
  };

  $scope.filter = Filter;
  $scope.filter.useGeo = true;

  //userID
  $scope.user = {
    ID: window.localStorage.getItem("plUserID"),
    RoleID: window.localStorage.getItem("plRoleID")
  };

  $scope.logOut = function () {
    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Logging out'
    });
    
    //process
    window.localStorage.removeItem("plUserID");
    window.localStorage.removeItem("plRoleID");
    window.localStorage.removeItem("plListingID");


    //loading timeout
    
    $timeout(function () {
      window.location.reload(true);
    }, 1000);
  };
})

.controller('RegisterCtrl', function ($scope, CommonCode, $ionicLoading, $http, $state, $timeout, $ionicViewService, Order, orderInfo, $rootScope) {

  $scope.submitForm = function(formInfo) {
    console.log(formInfo);

    //add type if not business
    if (!formInfo.business) {
      formInfo.type = "4";
    }

    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Registering User'
    });

    //processing
    $scope.submitted = true;

    $http.post('https://www.potlocator.com/api/createUser', formInfo).
    success(function(data, status, headers, config) {
      console.log(data);  
      if (data.errorCode === 0) {
        // SUCCESS
        //loading timeout
        $timeout(function () {    
          //loading timeout
          $timeout(function () {
            //send referer email if necessary
            if (orderInfo.ListingID) {
              // user/notify business
              $ionicLoading.hide();
              $ionicLoading.show({
                template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Notifying business'
              });
              $timeout(function () {
                //notify business
                Order.sendEmail(data.userID,orderInfo.ListingID);
                orderInfo.ListingID = "";
                // disable back button
                $ionicViewService.nextViewOptions({
                  disableAnimate: true,
                  disableBack: true
                });
                $state.go('thankyou');
                $ionicLoading.hide();
              }, 1000);
            }
            else if (formInfo.business) {
              //business
              $timeout(function () {
                window.localStorage.setItem("plUserID", data.userID);
                $rootScope.business_type_id = formInfo.type;
                $state.go('app.registerBusiness');
                $ionicLoading.hide();
              }, 1000);
            }
            else {
              // user
              $timeout(function () {
                $ionicLoading.hide();
                // disable back button
                $ionicViewService.nextViewOptions({
                  disableAnimate: true,
                  disableBack: true
                });
                $rootScope.firstLogin = true;
                $state.go('app.login');
              }, 1000);
            }
          }, 1000);
        }, 1000);
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError(data.errorText);
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
        CommonCode.alertError("Unable to register user, please try again later.");
      }, 0);
    });

  };
})

.controller('RegisterBusinessCtrl', function ($scope, CommonCode, $ionicLoading, $http, $state, $timeout, $ionicViewService, Order, orderInfo, $rootScope) {
  if ($rootScope.business_type_id) {
    $scope.formInfo = {business_type_id : Number($rootScope.business_type_id)};
  }
  else {
    $scope.formInfo = {business_type_id : 1};
  }

  $scope.submitForm = function(formInfo) {
    formInfo.created_by = window.localStorage.getItem("plUserID");
    formInfo.owned_by = window.localStorage.getItem("plUserID");
    formInfo.zipcode = Number(formInfo.zipcode);
    console.log(formInfo);

    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Registering Business'
    });

    //processing
    $scope.submitted = true;

    $http.post('https://www.potlocator.com/api/createListing', formInfo).
    success(function(data, status, headers, config) {
      if (data === true) {
        // SUCCESS
        //loading timeout
        $timeout(function () {
          // disable back button
          $ionicViewService.nextViewOptions({
            disableAnimate: true,
            disableBack: true
          });
          $rootScope.firstLoginBusiness = true;
          $state.go('app.login');   
          $ionicLoading.hide();
        }, 1000);
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError("Unable to register business, please try again later.");
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
        CommonCode.alertError("Unable to register business, please try again later.");
      }, 0);
    });

  };
})

.controller('LoginCtrl', function ($scope, CommonCode, $ionicLoading, $http, $state, $ionicViewService, $timeout, Order, orderInfo, $rootScope) {
  // check if first login
  $scope.firstLogin = $rootScope.firstLogin;
  $scope.firstLoginBusiness = $rootScope.firstLoginBusiness;

  $scope.submitForm = function(formInfo) {
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Logging in'
    });
    $scope.submitted = true;
    // console.log(formInfo);

    $http.post('https://www.potlocator.com/api/authenticateUser2', formInfo).
    success(function(data, status, headers, config) {
      console.log(data);

      if (data.ErrorCode === 0) {
        window.localStorage.setItem("plUserID", data.User.user_id);
        window.localStorage.setItem("plRoleID", data.Roles[0].RoleId);
        if (data.Listings.length) {
          window.localStorage.setItem("plListingID", data.Listings[0].id);
        }

        //send referer email if necessary
        if (orderInfo.ListingID) {
          $timeout(function () {

            $ionicLoading.hide();
            $ionicLoading.show({
              template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Notifying business'
            });
            $timeout(function () {
              //notify business
              Order.sendEmail(data.Data,orderInfo.ListingID);
              orderInfo.ListingID = "";

              // disable back button
              $ionicViewService.nextViewOptions({
                disableAnimate: true,
                disableBack: true
              });
              $state.go('thankyou');
              $ionicLoading.hide();
            }, 1000);
          }, 1000);
        }
        else {
          //loading timeout
          $timeout(function () {
            $state.go('app.search');
            $timeout(function () {
              window.location.reload(true);
            }, 1000);
          }, 1000);
        }
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError(data.ErrorText);
        }, 1000);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
        CommonCode.alertError("Unable to log in, please try again later.");
      }, 1000);
    });
  };
})

.controller('SearchCtrl', function($scope, $ionicLoading, $timeout, $ionicPlatform, $cordovaGeolocation, CommonCode, $http, $state, Filter) {
  //get Filter using factory
  $scope.filter = Filter;
  // console.log($scope.filter);

  // zipSearch
  $scope.zipSearch = function() {
    if (isNaN($scope.search.zip) === false && $scope.search.zip.toString().length == 5) {
      // console.log(0, 0, zip, $scope.filter.max_radius, $scope.filter.business_type_id);
      practices(0, 0, $scope.search.zip, $scope.filter.max_radius, $scope.filter.business_type_id);
    }
    else {
      CommonCode.alertError("Please enter a valid 5 digit zip code");
    }
  };

  // search
  $scope.search = function() {
    $scope.practices = null;

    if (!$scope.filter.useGeo) {
      //zip
      if (isNaN($scope.filter.zip) === false && $scope.filter.zip.toString().length == 5) {
        //valid zip
        practices(0, 0, $scope.filter.zip, $scope.filter.max_radius, $scope.filter.business_type_id);
      }
      else {
        //invaldi zip
        CommonCode.alertError("Please enter a valid 5 digit zip code");
      }
    }
    else {
      //geo
      $ionicLoading.show({
        template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Determining your current location'
      });

      //get location
      $ionicPlatform.ready(function() {
        var posOptions = {timeout: 10000, enableHighAccuracy: false};
        $cordovaGeolocation
          .getCurrentPosition(posOptions)
          .then(function (position) {
            //success
            var lat  = position.coords.latitude;
            var long = position.coords.longitude;
            //loading timeout
            $timeout(function () {
              $ionicLoading.hide();      
              practices(lat, long, 0, $scope.filter.max_radius, $scope.filter.business_type_id);

            }, 1000);
          }, function(err) {
            // error
            //loading timeout          
            $timeout(function () {
              $ionicLoading.hide();      
              CommonCode.alertError("We where unable to determine your location, please turn on your device's GPS location feature or use the zip code search filter");
            }, 1000);
          });
      });
    }

    
  };

  //auto load geo search preload
  $scope.search(); //comment while under dev

  $scope.viewListing = function(listing_id) {
    $state.go('app.listing',{id:listing_id});
    // console.log(listing_id);
  };

  function practices (lat, long, zip, max_radius, business_type_id) {
    $scope.practices = null;

    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Searching for businesses in your area'
    });

    var formInfo = {lat1:lat, lng1:long, zipcode:zip, max_radius:max_radius, business_type_id:business_type_id, take:15};

    $http.post('https://www.potlocator.com/api/GetListingsNearMe', formInfo).
    success(function(data, status, headers, config) {
      if (data.status == "OK" && Object.keys(data.Data).length !== 0) {
        //success
        //loading timeout
        $timeout(function () {
          console.log(data.Data);
          $scope.listings = data.Data;
          $ionicLoading.hide();  
        }, 1000);
      }
      else {
        // error
        //loading timeout
        $timeout(function () {
          CommonCode.alertError("We where unable to locate a business within the are specified, please adjust the search filter and try again.");
          $ionicLoading.hide();  
        }, 1000);
      }
    }).
    error(function(data, status, headers, config) {
      // error
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();  
        CommonCode.alertError("There was error while searching for businesses in your area, please try again later.");
      }, 1000);
      $ionicLoading.hide();
    });          
  }
})

.controller('ListingCtrl', function($scope, $state, $ionicLoading, $timeout, $ionicViewService, $stateParams, $ionicPlatform, $http, CommonCode, $ionicSlideBoxDelegate, $ionicPopup, Order, orderInfo) {  
  $ionicPlatform.ready(function() {
    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Loading practice'
    });

    //process
    var formInfo = {id:$stateParams.id};

    $scope.strainTypes = [{id:'Indica', name:'Indica', unit:'US'},{id:'Sativa', name:'Sativa', unit:'US'},{id:'Hybrid', name:'Hybrid', unit:'US'},{id:'Edible', name:'Edible', unit:'each'},{id:'Concentrate', name:'Concentrate', unit:'US'},{id:'Drinks', name:'Drinks', unit:'each'},{id:'Other_Products', name:'Other Products', unit:'each'},{id:'Clones', name:'Clones', unit:'US'},{id:'Seeds', name:'Seeds', unit:'each'},{id:'Grow_Equipment', name:'Grow Equipment', unit:'each'},{id:'Medical_Instruments', name:'Medical Instruments', unit:'each'},{id:'Vaporizers', name:'Vaporizers', unit:'each'},{id:'Medical_Products', name:'Medical Products', unit:'each'},{id:'Cannabis_Gear', name:'Cannabis Gear', unit:'each'},{id:'Tincture', name:'Tincture', unit:'each'},{id:'Bongs_and_Waterpipes', name:'Bongs and Waterpipes', unit:'each'},{id:'Smoking_Accessories', name:'Smoking Accessories', unit:'each'},{id:'Topicals', name:'Topicals', unit:'each'},{id:'Preroll', name:'Preroll', unit:'US'},{id:'Wax', name:'Wax', unit:'US'}];
    
    $http.post('https://www.potlocator.com/api/getDetailedListingMobile', formInfo).
    success(function(data, status, headers, config) {
      // console.log(data);
      //success
      if (data.status == "OK") {
        //double success
        $scope.listing = data.Data;
        $ionicSlideBoxDelegate.update();

        //check if strain types exists
        $scope.Indica = strainTypeExists(data.Data.Menu, "Indica");
        $scope.Sativa = strainTypeExists(data.Data.Menu, "Sativa");
        $scope.Hybrid = strainTypeExists(data.Data.Menu, "Hybrid");
        $scope.Edible = strainTypeExists(data.Data.Menu, "Edible");
        $scope.Concentrate = strainTypeExists(data.Data.Menu, "Concentrate");
        $scope.Drinks = strainTypeExists(data.Data.Menu, "Drinks");
        $scope.Other_Products = strainTypeExists(data.Data.Menu, "Other Products");
        $scope.Clones = strainTypeExists(data.Data.Menu, "Clones");
        $scope.Seeds = strainTypeExists(data.Data.Menu, "Seeds");
        $scope.Grow_Equipment = strainTypeExists(data.Data.Menu, "Grow Equipment");
        $scope.Medical_Instruments = strainTypeExists(data.Data.Menu, "Medical Instruments");
        $scope.Vaporizers = strainTypeExists(data.Data.Menu, "Vaporizers");
        $scope.Medical_Products = strainTypeExists(data.Data.Menu, "Medical Products");
        $scope.Cannabis_Gear = strainTypeExists(data.Data.Menu, "Cannabis Gear");
        $scope.Tincture = strainTypeExists(data.Data.Menu, "Tincture");
        $scope.Bongs_and_Waterpipes = strainTypeExists(data.Data.Menu, "Bongs and Waterpipes");
        $scope.Smoking_Accessories = strainTypeExists(data.Data.Menu, "Smoking Accessories");
        $scope.Topicals = strainTypeExists(data.Data.Menu, "Topicals");
        $scope.Preroll = strainTypeExists(data.Data.Menu, "Preroll");
        $scope.Wax = strainTypeExists(data.Data.Menu, "Wax");

        //loading timeout
        $timeout(function () {
          $ionicLoading.hide();  
        }, 1000);
      }
      else {
        // error
        //loading timeout
        $timeout(function () {
          CommonCode.alertError("There was error while retrieving information about this business, please try again later.");
          $ionicLoading.hide();  
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      // error
      //loading timeout
      $timeout(function () {
        CommonCode.alertError("There was error while retrieving information about this business, please try again later.");
        $ionicLoading.hide();  
      }, 0);
    });

    // place order
    $scope.placeOrder = function(){
      if (window.localStorage.getItem("plUserID")) {
        //logged in
        var confirmPopup = $ionicPopup.confirm({
          title: 'Place Order',
          template: '<div class="order-pop">This will notify the business of your interest and send the business your contact information.<br> Press OK to continue</div>',
          buttons: [
            { 
              text: 'Cancel',
            },
            {
              text: 'OK',
              type: 'button-balanced',
              onTap: function() {
                //notify business
                $ionicLoading.show({
                  template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Notifying business'
                });
   
                $timeout(function () {
                  Order.sendEmail(window.localStorage.getItem("plUserID"), $scope.listing.id);
                  $ionicLoading.hide();
                  // disable back button
                  $ionicViewService.nextViewOptions({
                    disableAnimate: true,
                    disableBack: true
                  });
                  $state.go('thankyou');
                }, 1000);
              }
            }
          ]
        });
      }
      else {
        // not logged in
        var registrationRequired = $ionicPopup.show({
          title: 'Registration Required',
          template: 'This will notify the business of your interest and send the business your contact information.<br> Please log in or register to continue',
          buttons: [
            { 
              text: 'Register',
              type: 'button-balanced',
              onTap: function() {
                orderInfo.ListingID = $scope.listing.id;
                $state.go('app.register');
              }
            },
            {
              text: 'Log In',
              type: 'button-balanced',
              onTap: function() {
                orderInfo.ListingID = $scope.listing.id;
                $state.go('app.login');
              }
            }
          ]
        });
      }
    };
  });

  function strainTypeExists(ary, value) {
     var match;
      for (var i = 0; i < ary.length; i++) {
         if (ary[i].strain_type == value) 
              return 1;
      }
  }
})

.controller('ThankyouCtrl', function ($scope, $ionicViewService, $state, $timeout, $ionicLoading) {
  $scope.goHome = function(){
    // disable back button
    $ionicViewService.nextViewOptions({
      disableAnimate: true,
      disableBack: true
    });
    $state.go('app.search');
/*    $timeout(function () {
      window.location.reload(true);
    }, 1000);*/

  };
})

.controller('DispensaryMarketplaceCtrl', function ($scope, $ionicViewService, $state, $timeout, $ionicLoading, $http, CommonCode, $rootScope, $ionicScrollDelegate) {
  $scope.getMarketplace = function(formInfo){
    $scope.strainTypes = [{id:'Indica', name:'Indica', unit:'US'},{id:'Sativa', name:'Sativa', unit:'US'},{id:'Hybrid', name:'Hybrid', unit:'US'},{id:'Edible', name:'Edible', unit:'each'},{id:'Concentrate', name:'Concentrate', unit:'US'},{id:'Drinks', name:'Drinks', unit:'each'},{id:'Other_Products', name:'Other Products', unit:'each'},{id:'Clones', name:'Clones', unit:'US'},{id:'Seeds', name:'Seeds', unit:'each'},{id:'Grow_Equipment', name:'Grow Equipment', unit:'each'},{id:'Medical_Instruments', name:'Medical Instruments', unit:'each'},{id:'Vaporizers', name:'Vaporizers', unit:'each'},{id:'Medical_Products', name:'Medical Products', unit:'each'},{id:'Cannabis_Gear', name:'Cannabis Gear', unit:'each'},{id:'Tincture', name:'Tincture', unit:'each'},{id:'Bongs_and_Waterpipes', name:'Bongs and Waterpipes', unit:'each'},{id:'Smoking_Accessories', name:'Smoking Accessories', unit:'each'},{id:'Topicals', name:'Topicals', unit:'each'},{id:'Preroll', name:'Preroll', unit:'US'},{id:'Wax', name:'Wax', unit:'US'}];

    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Loading The Marketplace'
    });

    $http.post('https://www.potlocator.com/api/GetMarketplace', formInfo).
    success(function(data, status, headers, config) {
      console.log(data);    
      if (data.ErrorCode === 0) {
        //success
        $scope.listing = data;

        //check if strain types exists
        $scope.Indica = strainTypeExists(data.Items, "Indica");
        $scope.Sativa = strainTypeExists(data.Items, "Sativa");
        $scope.Hybrid = strainTypeExists(data.Items, "Hybrid");
        $scope.Edible = strainTypeExists(data.Items, "Edible");
        $scope.Concentrate = strainTypeExists(data.Items, "Concentrate");
        $scope.Drinks = strainTypeExists(data.Items, "Drinks");
        $scope.Other_Products = strainTypeExists(data.Items, "Other Products");
        $scope.Clones = strainTypeExists(data.Items, "Clones");
        $scope.Seeds = strainTypeExists(data.Items, "Seeds");
        $scope.Grow_Equipment = strainTypeExists(data.Items, "Grow Equipment");
        $scope.Medical_Instruments = strainTypeExists(data.Items, "Medical Instruments");
        $scope.Vaporizers = strainTypeExists(data.Items, "Vaporizers");
        $scope.Medical_Products = strainTypeExists(data.Items, "Medical Products");
        $scope.Cannabis_Gear = strainTypeExists(data.Items, "Cannabis Gear");
        $scope.Tincture = strainTypeExists(data.Items, "Tincture");
        $scope.Bongs_and_Waterpipes = strainTypeExists(data.Items, "Bongs and Waterpipes");
        $scope.Smoking_Accessories = strainTypeExists(data.Items, "Smoking Accessories");
        $scope.Topicals = strainTypeExists(data.Items, "Topicals");
        $scope.Preroll = strainTypeExists(data.Items, "Preroll");
        $scope.Wax = strainTypeExists(data.Items, "Wax");

        //loading timeout
        $timeout(function () {
          $ionicLoading.hide();  
        }, 1000);

        //loading timeout
        $timeout(function () {
          $ionicLoading.hide();  
        }, 1000);
      }
      else {
        // error
        //loading timeout
        $timeout(function () {
          CommonCode.alertError(data.ErrorText);
          $ionicLoading.hide();  
        }, 1000);
      }
    }).
    error(function(data, status, headers, config) {
      // error
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();  
        CommonCode.alertError("There was error while loading the marketplace, please try again later.");
      }, 1000);
      $ionicLoading.hide();
    });          
  };

  $scope.addToCart = function(formInfo2){
    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Adding to cart'
    });

    formInfo2.user_id = window.localStorage.getItem("plUserID");
    formInfo2.deliver = true;
    console.log(formInfo2);

    $http.post('https://www.potlocator.com/api/addStrainToMobileCart', formInfo2).
    success(function(data, status, headers, config) {
      console.log(data);
      if (data.status == "OK") {
        // success
        //loading timeout
        $timeout(function () {
          $scope.orderSuccess = true;
          $ionicLoading.hide();
        }, 1000);
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError("Unable to place order, please try again later.");
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
      }, 0);
    });
  };

  $scope.isNumber = angular.isNumber;

  $scope.scrollTop = function() {
    $ionicScrollDelegate.scrollTop();
  };

  $scope.goToCart = function() {
    $state.go('app.dispensary-cart', {}, {reload: true});
  };


  function strainTypeExists(ary, value) {
     var match;
      for (var i = 0; i < ary.length; i++) {
        if (ary[i].strain_type == value) 
          return 1;
      }
  }
})

.controller('DispensaryCartCtrl', function ($scope, $ionicViewService, $state, $timeout, $ionicLoading, $http, CommonCode, $rootScope, $ionicScrollDelegate) {
  getCart();
  function getCart() {
    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Loading Cart'
    });

    formInfo = {user_id : window.localStorage.getItem("plUserID")};

    $http.post('https://www.potlocator.com/api/getMobileCart', formInfo).
    success(function(data, status, headers, config) {
      if (data.status == "OK") {
        $timeout(function () {
          // success
          $scope.items = data.Data.strains;

          $scope.total = 0;
          for (var i = 0; i < $scope.items.length; i++) {
            $scope.total += $scope.items[i].unitprice * $scope.items[i].qty;
          }

          $ionicLoading.hide();
        }, 1000);      
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError(data.message);
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
      }, 0);
    });
  }

  $scope.submitForm = function(formInfo){
    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Checking Out'
    });

    formInfo.user_id = window.localStorage.getItem("plUserID");

    $http.post('https://www.potlocator.com/api/checkoutMobileCart', formInfo).
    success(function(data, status, headers, config) {
      if (data.status == "OK") {
        // success
        $timeout(function () {
          $scope.items = "";
          // $scope.checkoutForm.$setPristine();
          $scope.orderSuccess = true;
          $ionicScrollDelegate.scrollTop();
          $ionicLoading.hide();
        }, 1000);
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError(data.Data);
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
      }, 0);
    });
  };

  $scope.removeItem = function(id, listing_id){
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Removing item'
    });

    formInfo = {
      user_id : window.localStorage.getItem("plUserID"),
      id : id,
      listing_id : listing_id
    };

    $http.post('https://www.potlocator.com/api/removeStrainFromMobileCart', formInfo).
    success(function(data, status, headers, config) {
      if (data.status == "OK") {
        // success
        $timeout(function () {
          $ionicLoading.hide();
          getCart();
        }, 1000);
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError(data.Data);
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
      }, 0);
    });
  };
})

.controller('VendorMenuCtrl', function ($scope, $ionicViewService, $state, $timeout, $ionicLoading, $http, CommonCode, $ionicModal) {
  marketplace();

  function marketplace () {
    $scope.practices = null;


    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Loading Your Products'
    });

    // var formInfo = {lat1:lat, lng1:long, zipcode:zip, max_radius:max_radius, business_type_id:business_type_id, take:15};
    var formInfo = {listing_id: window.localStorage.getItem("plListingID")};

    $http.post('https://www.potlocator.com/api/GetMenu', formInfo).
    success(function(data, status, headers, config) {
      console.log(data);    
      if (data.ErrorCode === 0) {
        if (Object.keys(data.Menu).length !== 0) {
          //success
          $scope.listing = data;

          //check if strain types exists
          $scope.Indica = strainTypeExists(data.Menu, "Indica");
          $scope.Sativa = strainTypeExists(data.Menu, "Sativa");
          $scope.Hybrid = strainTypeExists(data.Menu, "Hybrid");
          $scope.Edible = strainTypeExists(data.Menu, "Edible");
          $scope.Concentrate = strainTypeExists(data.Menu, "Concentrate");
          $scope.Drinks = strainTypeExists(data.Menu, "Drinks");
          $scope.Other_Products = strainTypeExists(data.Menu, "Other Products");
          $scope.Clones = strainTypeExists(data.Menu, "Clones");
          $scope.Seeds = strainTypeExists(data.Menu, "Seeds");
          $scope.Grow_Equipment = strainTypeExists(data.Menu, "Grow Equipment");
          $scope.Medical_Instruments = strainTypeExists(data.Menu, "Medical Instruments");
          $scope.Vaporizers = strainTypeExists(data.Menu, "Vaporizers");
          $scope.Medical_Products = strainTypeExists(data.Menu, "Medical Products");
          $scope.Cannabis_Gear = strainTypeExists(data.Menu, "Cannabis Gear");
          $scope.Tincture = strainTypeExists(data.Menu, "Tincture");
          $scope.Bongs_and_Waterpipes = strainTypeExists(data.Menu, "Bongs and Waterpipes");
          $scope.Smoking_Accessories = strainTypeExists(data.Menu, "Smoking Accessories");
          $scope.Topicals = strainTypeExists(data.Menu, "Topicals");
          $scope.Preroll = strainTypeExists(data.Menu, "Preroll");
          $scope.Wax = strainTypeExists(data.Menu, "Wax");

          //loading timeout
          $timeout(function () {
            $ionicLoading.hide();  
          }, 1000);

          //loading timeout
          $timeout(function () {
            $ionicLoading.hide();  
          }, 1000);
        }
        else {
          //empty
          //loading timeout
          $timeout(function () {
            $ionicLoading.hide();  
          }, 1000);
        }
      }
      else {
        // error
        //loading timeout
        $timeout(function () {
          CommonCode.alertError(data.ErrorText);
          $ionicLoading.hide();  
        }, 1000);
      }
    }).
    error(function(data, status, headers, config) {
      // error
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();  
        CommonCode.alertError("There was error while loading your products, please try again later.");
      }, 1000);
      $ionicLoading.hide();
    });          
  }

  function strainTypeExists(ary, value) {
     var match;
      for (var i = 0; i < ary.length; i++) {
        if (ary[i].strain_type == value) 
          return 1;
      }
  }
})

.controller('VendorMenuAddCtrl', function ($scope, CommonCode, $ionicLoading, $http, $state, $timeout, $ionicViewService, Order, orderInfo, $cordovaCamera, $cordovaInstagram) {
  $scope.useCamera = function(formInfo) {
    var options = {
      quality: 50,
      destinationType: Camera.DestinationType.DATA_URL,
      sourceType: Camera.PictureSourceType.CAMERA,
      allowEdit: false,
      encodingType: Camera.EncodingType.JPEG,
      // targetWidth: 500,
      // targetHeight: 500,
      popoverOptions: CameraPopoverOptions,
      saveToPhotoAlbum: false
    };

    $cordovaCamera.getPicture(options).then(function(imageData) {
      $scope.imageURI = "data:image/jpeg;base64," + imageData;
      $scope.imageData = imageData;
    }, function(err) {
      // error
    });
  };

  $scope.submitForm = function(formInfo) {
    //add listing_id
    formInfo.listing_id = window.localStorage.getItem("plListingID");
      
    if ($scope.imageData) {
      formInfo.encimage = $scope.imageData;
      formInfo.imagetype = "image/jpeg";
    }
    
    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Saving Menu Item'
    });

    //processing
    $scope.submitted = true;

    console.log(formInfo);


    $http.post('https://www.potlocator.com/api/saveMenu2', formInfo).
    success(function(data, status, headers, config) {
      console.log(data);
      if (data.ErrorCode === 0) {
        // success
        //loading timeout
        $timeout(function () {            
          $state.go('app.vendor-menu', {}, {reload: true}); //
          $ionicLoading.hide();
        }, 1000);
      }
      else {
        //error
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError(data.ErrorText);
        }, 0);
      }
    }).
    error(function(data, status, headers, config) {
      //loading timeout
      $timeout(function () {
        $ionicLoading.hide();
        CommonCode.alertError("Unable to save menu, please try again later.");
      }, 0);
    });
  };

  $scope.submitInstagram = function() {
    //loading
    $ionicLoading.show({
      template: '<ion-spinner icon="bubbles" class="spinner-balanced"></ion-spinner><br>Adding product via Instagram'
    });

    // Get image from camera, base64 is good. See the $cordovaCamera docs for more info
    $cordovaInstagram.share({image: $scope.imageURI, caption: ''}).then(function() {
      // Worked
      //loading timeout
      $timeout(function () {            
        $state.go('app.vendor-menu', {}, {reload: true}); //
        $ionicLoading.hide();
      }, 1000);
    }, function(err) {
      // Didn't work
      $state.go('app.vendor-menu', {}, {reload: true}); //
      // CommonCode.alertError(err);
      console.log(err);
      $ionicLoading.hide();
    });
  };


  $scope.getStrains = function(id, term) {
    if (typeof term !== 'undefined' && term.length >= 4) {
      $http.get('https://www.potlocator.com/api/getStrains'+'/?id='+id+'&term='+term).
      success(function(data, status, headers, config) {
        console.log(data);
        if (data.length !== 0) {
          // success
          var products = data.slice(0,10);
          $scope.products = products;
        }
        else {
          //error
          console.log("no results");
        }
      }).
      error(function(data, status, headers, config) {
        //loading timeout
        $timeout(function () {
          $ionicLoading.hide();
          CommonCode.alertError("Unable to get products, please try again later.");
        }, 0);
      });
    }
    else {
      $scope.products = "";
    }
  };

  $scope.clearProducts = function(id, term) {
      $scope.products = "";
  };

});